/* ================================================================
 * EnhancedPreferences API - Alternative preferences package
 * ================================================================
 * 
 * Project Info:  http://development.poopu.com/ehprefs
 * Project Lead:  Justin Kim(jst.kim@gmail.com)
 * Create Date : 2004. 12. 16
 *
 * (C) Copyright 2004, by Justin Kim
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.poopu.util.prefs.hibernate.impl;

import java.sql.Connection;
import java.util.ArrayList;

import net.sf.hibernate.Criteria;
import net.sf.hibernate.HibernateException;
import net.sf.hibernate.Session;
import net.sf.hibernate.SessionFactory;
import net.sf.hibernate.Transaction;

import org.jmock.Mock;
import org.jmock.core.matcher.InvokeAtLeastOnceMatcher;
import org.jmock.core.matcher.InvokeOnceMatcher;
import org.jmock.core.stub.ReturnStub;
import org.jmock.core.stub.VoidStub;

import com.poopu.util.prefs.hibernate.HibernateManager;

/**
 * @author jskim
 *  
 */
public class MockHibernateManager implements HibernateManager
{

  public MockHibernateManager()
  {

  }

  /*
   * (non-Javadoc)
   * 
   * @see com.poopu.util.prefs.hibernate.HibernateManager#getSessionFactory()
   */
  public SessionFactory getSessionFactory() throws HibernateException
  {
    Mock mockSf = new Mock(SessionFactory.class);
    Mock mockSession = new Mock(Session.class);
    mockSession.expects(new InvokeOnceMatcher()).method("close").will(new VoidStub());
    mockSf.expects(new InvokeOnceMatcher()).method("openSession").will(
        new ReturnStub(mockSession.proxy()));

    Mock mockCriteria = new Mock(Criteria.class);
    mockCriteria.expects(new InvokeAtLeastOnceMatcher()).method("add").will(new VoidStub());
    mockCriteria.expects(new InvokeOnceMatcher()).method("list").will(
        new ReturnStub(new ArrayList()));
    mockSession.expects(new InvokeOnceMatcher()).method("createCriteria").will(
        new ReturnStub(mockCriteria.proxy()));

    Mock mockTx = new Mock(Transaction.class);
    mockTx.expects(new InvokeAtLeastOnceMatcher()).method("commit").will(new VoidStub());
    mockSession.expects(new InvokeAtLeastOnceMatcher()).method("beginTransaction").will(
        new ReturnStub(mockTx.proxy()));

    mockSession.expects(new InvokeAtLeastOnceMatcher()).method("save").will(new VoidStub());

    SessionFactory sf = (SessionFactory) mockSf.proxy();
    return sf;
  }

  /*
   * (non-Javadoc)
   * 
   * @see com.poopu.util.prefs.hibernate.HibernateManager#openSession()
   */
  public Session openSession() throws HibernateException
  {
    return getSessionFactory().openSession();
  }

  /*
   * (non-Javadoc)
   * 
   * @see com.poopu.util.prefs.hibernate.HibernateManager#openSession(java.sql.Connection)
   */
  public Session openSession(Connection con) throws HibernateException
  {
    // TODO Auto-generated method stub
    return null;
  }

}